@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 #else
 #ifndef E_ATOMS_H
@@ -28,8 +25,8 @@ extern EAPI Ecore_X_Atom E_ATOM_DESKTOP_FILE;
 extern EAPI Ecore_X_Atom E_ATOM_WINDOW_STATE;
 extern EAPI Ecore_X_Atom E_ATOM_WINDOW_STATE_CENTERED;
 
-EAPI int    e_atoms_init(void);
-EAPI int    e_atoms_shutdown(void);
+EINTERN int    e_atoms_init(void);
+EINTERN int    e_atoms_shutdown(void);
 
 #endif
 #endif
