@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Exec_Instance E_Exec_Instance;
@@ -19,8 +16,8 @@ struct _E_Exec_Instance
    Ecore_Timer    *expire_timer;
 };
 
-EAPI int  e_exec_init(void);
-EAPI int  e_exec_shutdown(void);
+EINTERN int  e_exec_init(void);
+EINTERN int  e_exec_shutdown(void);
 EAPI E_Exec_Instance *e_exec(E_Zone *zone, Efreet_Desktop *desktop, const char *exec, Eina_List *files, const char *launch_method);
 
 EAPI Efreet_Desktop *e_exec_startup_id_pid_find(int startup_id, pid_t pid);
