@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 #ifdef USE_IPC
@@ -28,8 +25,8 @@ typedef int E_Ipc_Op;
 #ifndef E_IPC_H
 #define E_IPC_H
 
-EAPI int e_ipc_init(void);
-EAPI int e_ipc_shutdown(void);
+EINTERN int e_ipc_init(void);
+EINTERN int e_ipc_shutdown(void);
 
 #endif
 #endif
