@@ -1,10 +1,7 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
  
 EAPI int
-e_mouse_init(void)
+e_mouse_update(void)
 {
    unsigned char map[256];
    int n;
