@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Pointer E_Pointer;
@@ -39,8 +36,8 @@ struct _E_Pointer
    } hot;
 };
 
-EAPI int        e_pointer_init(void);
-EAPI int        e_pointer_shutdown(void);    
+EINTERN int        e_pointer_init(void);
+EINTERN int        e_pointer_shutdown(void);    
 EAPI E_Pointer *e_pointer_window_new(Ecore_X_Window win, int filled);
 EAPI void	e_pointer_hide(E_Pointer *p);
 EAPI void       e_pointer_type_push(E_Pointer *p, void *obj, const char *type);
