@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 
 typedef struct _E_Screen E_Screen;
@@ -15,8 +12,8 @@ struct _E_Screen
    int x, y, w, h;
 };
 
-EAPI int              e_xinerama_init(void);
-EAPI int              e_xinerama_shutdown(void);
+EINTERN int              e_xinerama_init(void);
+EINTERN int              e_xinerama_shutdown(void);
 EAPI void             e_xinerama_update(void);
 EAPI const Eina_List *e_xinerama_screens_get(void);
 EAPI const Eina_List *e_xinerama_screens_all_get(void);
