@@ -754,24 +754,26 @@ static void
 _bluez_menu_new(E_Bluez_Instance *inst, Evas_Event_Mouse_Down *ev)
 {
    E_Zone *zone;
-   E_Menu *mn;
+   E_Menu *ma, *mg;
    E_Menu_Item *mi;
    int x, y;
 
    zone = e_util_zone_current_get(e_manager_current_get());
 
-   mn = e_menu_new();
-   e_menu_post_deactivate_callback_set(mn, _bluez_menu_cb_post, inst);
-   inst->menu = mn;
+   ma = e_menu_new();
+   e_menu_post_deactivate_callback_set(ma, _bluez_menu_cb_post, inst);
+   inst->menu = ma;
 
-   mi = e_menu_item_new(mn);
+   mg = e_menu_new();
+
+   mi = e_menu_item_new(mg);
    e_menu_item_label_set(mi, _("Settings"));
    e_util_menu_item_theme_icon_set(mi, "configure");
    e_menu_item_callback_set(mi, _bluez_menu_cb_cfg, inst);
 
-   e_gadcon_client_util_menu_items_append(inst->gcc, mn, 0);
+   e_gadcon_client_util_menu_items_append(inst->gcc, ma, mg, 0);
    e_gadcon_canvas_zone_geometry_get(inst->gcc->gadcon, &x, &y, NULL, NULL);
-   e_menu_activate_mouse(mn, zone, x + ev->output.x, y + ev->output.y,
+   e_menu_activate_mouse(ma, zone, x + ev->output.x, y + ev->output.y,
                          1, 1, E_MENU_POP_DIRECTION_AUTO, ev->timestamp);
    evas_event_feed_mouse_up(inst->gcc->gadcon->evas, ev->button,
                             EVAS_BUTTON_NONE, ev->timestamp, NULL);
@@ -1310,7 +1312,7 @@ e_modapi_init(E_Module *m)
      return NULL;
 
    ctxt->agent.conn = e_dbus_bus_get(DBUS_BUS_SYSTEM);
-   if (!e_bluez_system_init(ctxt->agent.conn))
+   if ((!ctxt->agent.conn) || (!e_bluez_system_init(ctxt->agent.conn)))
      goto error_bluez_system_init;
 
    bluez_mod = m;
