@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 #include "e_mod_main.h"
 
@@ -17,18 +14,23 @@ EAPI E_Module_Api e_modapi =
 EAPI void *
 e_modapi_init(E_Module *m)
 {
-   e_configure_registry_category_add("screen", 30, _("Screen"), NULL, "preferences-desktop-display");
-   e_configure_registry_item_add("screen/screen_lock", 30, _("Screen Lock"), NULL, "preferences-desklock", e_int_config_desklock);
+   e_configure_registry_category_add("screen", 30, _("Screen"), NULL, 
+                                     "preferences-desktop-display");
+   e_configure_registry_item_add("screen/screen_lock", 30, _("Screen Lock"), 
+                                 NULL, "preferences-desklock", 
+                                 e_int_config_desklock);
    conf_module = m;
    e_module_delayed_set(m, 1);
    return m;
 }
 
 EAPI int
-e_modapi_shutdown(E_Module *m)
+e_modapi_shutdown(E_Module *m __UNUSED__)
 {
    E_Config_Dialog *cfd;
-   while ((cfd = e_config_dialog_get("E", "screen/screen_lock"))) e_object_del(E_OBJECT(cfd));
+
+   while ((cfd = e_config_dialog_get("E", "screen/screen_lock"))) 
+     e_object_del(E_OBJECT(cfd));
    e_configure_registry_item_del("screen/screen_lock");
    e_configure_registry_category_del("screen");
    conf_module = NULL;
@@ -36,7 +38,7 @@ e_modapi_shutdown(E_Module *m)
 }
 
 EAPI int
-e_modapi_save(E_Module *m)
+e_modapi_save(E_Module *m __UNUSED__)
 {
    return 1;
 }
