@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 #include "e_int_config_imc.h"
 #include "e_int_config_imc_import.h"
@@ -151,7 +148,7 @@ _change_hash_free_cb(const Eina_Hash *hash __UNUSED__, const void *key __UNUSED_
 }
 
 static void
-_free_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
+_free_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 {
    if (cfdata->win_import)
      e_int_config_imc_import_del(cfdata->win_import);
@@ -181,7 +178,7 @@ _free_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 
 /*** Start Basic Dialog Logic ***/
 static int
-_basic_apply_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
+_basic_apply_data(E_Config_Dialog *cfd __UNUSED__, E_Config_Dialog_Data *cfdata)
 {
    if (cfdata->imc_current)
      {
@@ -225,7 +222,7 @@ _e_imc_setup_button_toggle(Evas_Object *button, E_Input_Method_Config *imc)
 }
 
 static void
-_e_imc_list_change_cb(void *data, Evas_Object *obj)
+_e_imc_list_change_cb(void *data, Evas_Object *obj __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    E_Input_Method_Config *imc;
@@ -241,7 +238,7 @@ _e_imc_list_change_cb(void *data, Evas_Object *obj)
 }
 
 static void
-_e_imc_setup_cb(void *data, void *data2)
+_e_imc_setup_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -430,7 +427,7 @@ _advanced_apply_data(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
 
 /* Radio Toggled */
 static void
-_cb_dir(void *data, Evas_Object *obj)
+_cb_dir(void *data, Evas_Object *obj __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    const char *path;
@@ -445,7 +442,7 @@ _cb_dir(void *data, Evas_Object *obj)
 
 /* Directory Navigator */
 static void
-_cb_button_up(void *data, void *data2)
+_cb_button_up(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -458,7 +455,7 @@ _cb_button_up(void *data, void *data2)
 
 /* Entry chagned */
 static void
-_e_imc_entry_change_cb(void *data, Evas_Object *obj)
+_e_imc_entry_change_cb(void *data, Evas_Object *obj __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -468,7 +465,7 @@ _e_imc_entry_change_cb(void *data, Evas_Object *obj)
 
 /* Creating a new IMC */
 static void
-_cb_new(void *data, void *data2)
+_cb_new(void *data, void *data2 __UNUSED__)
 {
    E_Input_Method_Config *imc_new;
    Eet_File *ef;
@@ -495,7 +492,7 @@ _cb_new(void *data, void *data2)
 }
 
 static void
-_e_imc_adv_setup_cb(void *data, void *data2)
+_e_imc_adv_setup_cb(void *data, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -524,7 +521,7 @@ _e_imc_adv_setup_cb(void *data, void *data2)
 
 /** Start IMC FM2 Callbacks **/
 static void
-_cb_files_changed(void *data, Evas_Object *obj, void *event_info)
+_cb_files_changed(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
@@ -545,7 +542,7 @@ _cb_files_changed(void *data, Evas_Object *obj, void *event_info)
 }
 
 static void
-_cb_files_selection_change(void *data, Evas_Object *obj, void *event_info)
+_cb_files_selection_change(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    Eina_List *selected;
@@ -579,7 +576,7 @@ _cb_files_selection_change(void *data, Evas_Object *obj, void *event_info)
 }
 
 static void
-_cb_files_files_changed(void *data, Evas_Object *obj, void *event_info)
+_cb_files_files_changed(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    const char *buf;
    const char *p;
@@ -609,7 +606,7 @@ _cb_files_files_changed(void *data, Evas_Object *obj, void *event_info)
 }
 
 static void
-_cb_files_files_deleted(void *data, Evas_Object *obj, void *event_info)
+_cb_files_files_deleted(void *data, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
    Eina_List *sel, *all, *n;
@@ -760,7 +757,7 @@ e_int_config_imc_import_done(E_Config_Dialog *dia)
 }
 
 static void
-_cb_import(void *data1, void *data2)
+_cb_import(void *data1, void *data2 __UNUSED__)
 {
    E_Config_Dialog_Data *cfdata;
 
