@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 #include "e_mod_main.h"
 
@@ -17,8 +14,12 @@ EAPI E_Module_Api e_modapi =
 EAPI void *
 e_modapi_init(E_Module *m)
 {
-   e_configure_registry_category_add("keyboard_and_mouse", 40, _("Input"), NULL, "preferences-behavior");
-   e_configure_registry_item_add("keyboard_and_mouse/mouse_settings", 30, _("Mouse Settings"), NULL, "preferences-desktop-mouse", e_int_config_mouse);
+   e_configure_registry_category_add("keyboard_and_mouse", 40, _("Input"), 
+                                     NULL, "preferences-behavior");
+   e_configure_registry_item_add("keyboard_and_mouse/mouse_settings", 30, 
+                                 _("Mouse Settings"), NULL, 
+                                 "preferences-desktop-mouse", 
+                                 e_int_config_mouse);
    conf_module = m;
    e_module_delayed_set(m, 1);
    return m;
@@ -28,7 +29,9 @@ EAPI int
 e_modapi_shutdown(E_Module *m __UNUSED__)
 {
    E_Config_Dialog *cfd;
-   while ((cfd = e_config_dialog_get("E", "keyboard_and_mouse/mouse_settings"))) e_object_del(E_OBJECT(cfd));
+
+   while ((cfd = e_config_dialog_get("E", "keyboard_and_mouse/mouse_settings"))) 
+     e_object_del(E_OBJECT(cfd));
    e_configure_registry_item_del("keyboard_and_mouse/mouse_settings");
    e_configure_registry_category_del("keyboard_and_mouse");
    conf_module = NULL;
