@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #include "e.h"
 #include "e_mod_main.h"
 
@@ -18,18 +15,22 @@ EAPI E_Module_Api e_modapi =
 EAPI void *
 e_modapi_init(E_Module *m)
 {
-   e_configure_registry_category_add("appearance", 10, _("Look"), NULL, "preferences-appearance");
-   e_configure_registry_item_add("appearance/scale", 90, _("Scaling"), NULL, "preferences-scale", e_int_config_scale);
+   e_configure_registry_category_add("appearance", 10, _("Look"), 
+                                     NULL, "preferences-look");
+   e_configure_registry_item_add("appearance/scale", 90, _("Scaling"), NULL, 
+                                 "preferences-scale", e_int_config_scale);
    conf_module = m;
    e_module_delayed_set(m, 1);
    return m;
 }
 
 EAPI int
-e_modapi_shutdown(E_Module *m)
+e_modapi_shutdown(E_Module *m __UNUSED__)
 {
    E_Config_Dialog *cfd;
-   while ((cfd = e_config_dialog_get("E", "appearance/scale"))) e_object_del(E_OBJECT(cfd));
+
+   while ((cfd = e_config_dialog_get("E", "appearance/scale"))) 
+     e_object_del(E_OBJECT(cfd));
    e_configure_registry_item_del("appearance/scale");
    e_configure_registry_category_del("appearance");
    conf_module = NULL;
@@ -37,7 +38,7 @@ e_modapi_shutdown(E_Module *m)
 }
 
 EAPI int
-e_modapi_save(E_Module *m)
+e_modapi_save(E_Module *m __UNUSED__)
 {
    return 1;
 }
