@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifdef E_TYPEDEFS
 typedef struct _E_Config_Wallpaper E_Config_Wallpaper;
 #else
@@ -12,7 +9,6 @@ E_Config_Dialog *e_int_config_wallpaper_desk(E_Container *con, const char *param
 
 void e_int_config_wallpaper_update(E_Config_Dialog *dia, char *file);
 void e_int_config_wallpaper_import_done(E_Config_Dialog *dia);
-void e_int_config_wallpaper_gradient_done(E_Config_Dialog *dia);
 void e_int_config_wallpaper_web_done(E_Config_Dialog *dia);
 
 #endif
