@@ -1,10 +1,7 @@
 #include "e.h"
 #include "e_kbd_dict.h"
 
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <sys/mman.h>
 
 #define MAXLATIN 0x100
@@ -177,7 +174,7 @@ _e_kbd_dict_line_next(E_Kbd_Dict *kd, const char *p)
 }
 
 static char *
-_e_kbd_dict_line_parse(E_Kbd_Dict *kd, const char *p, int *usage)
+_e_kbd_dict_line_parse(E_Kbd_Dict *kd __UNUSED__, const char *p, int *usage)
 {
    const char *ps;
    char *wd = NULL;
@@ -197,12 +194,11 @@ _e_kbd_dict_line_parse(E_Kbd_Dict *kd, const char *p, int *usage)
 }
 
 static void
-_e_kbd_dict_lookup_build_line(E_Kbd_Dict *kd, const char *p, const char *eol, 
-			      int *glyphs)
+_e_kbd_dict_lookup_build_line(E_Kbd_Dict *kd __UNUSED__, const char *p, const char *eol, int *glyphs)
 {
    char *s;
    int p2;
-   
+
    s = alloca(eol - p + 1);
    strncpy(s, p, eol - p);
    s[eol - p] = 0;
@@ -274,7 +270,7 @@ _e_kbd_dict_open(E_Kbd_Dict *kd)
    kd->file.size = st.st_size;
    kd->file.dict = mmap(NULL, kd->file.size, PROT_READ, MAP_SHARED,
 			kd->file.fd, 0);
-   if ((kd->file.dict== MAP_FAILED) || (kd->file.dict == NULL))
+   if ((kd->file.dict== MAP_FAILED) || (!kd->file.dict))
      {
 	close(kd->file.fd);
 	return 0;
@@ -694,17 +690,15 @@ e_kbd_dict_word_letter_delete(E_Kbd_Dict *kd)
 }
 
 static void
-_e_kbd_dict_matches_lookup_iter(E_Kbd_Dict *kd, Eina_List *word,
-				Eina_List *more)
+_e_kbd_dict_matches_lookup_iter(E_Kbd_Dict *kd, Eina_List *word, Eina_List *more)
 {
-   Eina_List *l, *l2, *list;
-   const char *p, *pn;
+   Eina_List *l, *list;
+   const char *p;
    char *base, *buf, *wd, *bufapp;
    E_Kbd_Dict_Letter *kl;
    int len, dist = 0, d, baselen, maxdist = 0, md;
-   
-   static int level = 0, lv;
-   
+   static int level = 0;
+
    len = 0;
    level++;
    for (l = word; l; l = l->next)
@@ -762,7 +756,7 @@ _e_kbd_dict_matches_lookup_iter(E_Kbd_Dict *kd, Eina_List *word,
 	       {
 		  E_Kbd_Dict_Word *kw;
 		  int usage = 0;
-		  
+
 		  wd = _e_kbd_dict_line_parse(kd, p, &usage);
 		  if (!wd) break;
 		  if (_e_kbd_dict_normalized_strcmp(wd, buf))
@@ -774,8 +768,8 @@ _e_kbd_dict_matches_lookup_iter(E_Kbd_Dict *kd, Eina_List *word,
 		  if (kw)
 		    {
 		       int accuracy;
-		       int w, b, w2, b2, wc, bc, upper;
-		       
+		       int w, b, w2, b2, wc, bc;
+
 		       // match any capitalisation
 		       for (w = 0, b = 0; wd[w] && buf[b];)
 			 {
@@ -787,12 +781,12 @@ _e_kbd_dict_matches_lookup_iter(E_Kbd_Dict *kd, Eina_List *word,
 			 }
 		       kw->word = eina_stringshare_add(wd);
 		       // FIXME: magic combination of distance metric and
-		       // frequency of useage. this is simple now, but could
+		       // frequency of usage. this is simple now, but could
 		       // be tweaked
 		       wc = eina_list_count(word);
 		       if (md < 1) md = 1;
 		       
-		       // basically a metric to see how far away teh keys that
+		       // basically a metric to see how far away the keys that
 		       // were actually pressed are away from the letters of
 		       // this word in a physical on-screen sense
 		       accuracy = md - (d / (wc + 1));
