@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 /* TODO: config dialog to select which modem to monitor */
 
 #include "e.h"
@@ -229,18 +225,20 @@ static void
 _ofono_menu_new(E_Ofono_Instance *inst, Evas_Event_Mouse_Down *ev)
 {
    E_Zone *zone;
-   E_Menu *mn;
+   E_Menu *ma, *mg;
    int x, y;
 
    zone = e_util_zone_current_get(e_manager_current_get());
 
-   mn = e_menu_new();
-   e_menu_post_deactivate_callback_set(mn, _ofono_menu_cb_post, inst);
-   inst->menu = mn;
+   ma = e_menu_new();
+   e_menu_post_deactivate_callback_set(ma, _ofono_menu_cb_post, inst);
+   inst->menu = ma;
 
-   e_gadcon_client_util_menu_items_append(inst->gcc, mn, 0);
+   mg = e_menu_new();
+
+   e_gadcon_client_util_menu_items_append(inst->gcc, ma, mg, 0);
    e_gadcon_canvas_zone_geometry_get(inst->gcc->gadcon, &x, &y, NULL, NULL);
-   e_menu_activate_mouse(mn, zone, x + ev->output.x, y + ev->output.y,
+   e_menu_activate_mouse(ma, zone, x + ev->output.x, y + ev->output.y,
                          1, 1, E_MENU_POP_DIRECTION_AUTO, ev->timestamp);
    evas_event_feed_mouse_up(inst->gcc->gadcon->evas, ev->button,
                             EVAS_BUTTON_NONE, ev->timestamp, NULL);
