@@ -1,6 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 #ifndef E_MOD_MAIN_H
 #define E_MOD_MAIN_H
 
@@ -24,6 +21,7 @@ struct _Config
    double popup_speed;
    unsigned int popup_urgent;
    unsigned int popup_urgent_stick;
+   unsigned int popup_urgent_focus;
    double popup_urgent_speed;
    unsigned int show_desk_names;
    int popup_act_height; /*keyaction popup */
