@@ -1,25 +1,22 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
 /* Splash Screen */
 
 #include "e.h"
 #include "e_mod_main.h"
 
 EAPI int
-wizard_page_init(E_Wizard_Page *pg)
+wizard_page_init(E_Wizard_Page *pg __UNUSED__)
 {
    return 1;
 }
 
 EAPI int
-wizard_page_shutdown(E_Wizard_Page *pg)
+wizard_page_shutdown(E_Wizard_Page *pg __UNUSED__)
 {
    return 1;
 }
 
 static Eina_Bool
-_next_page(__UNUSED__ void *data)
+_next_page(void *data __UNUSED__)
 {
    e_wizard_button_next_enable_set(1);
    e_wizard_next();
@@ -27,7 +24,7 @@ _next_page(__UNUSED__ void *data)
 }
 
 EAPI int
-wizard_page_show(E_Wizard_Page *pg)
+wizard_page_show(E_Wizard_Page *pg __UNUSED__)
 {
    e_wizard_title_set(_("Enlightenment"));
    e_wizard_button_next_enable_set(0);
@@ -36,13 +33,13 @@ wizard_page_show(E_Wizard_Page *pg)
 }
 
 EAPI int
-wizard_page_hide(E_Wizard_Page *pg)
+wizard_page_hide(E_Wizard_Page *pg __UNUSED__)
 {
    return 1;
 }
 
 EAPI int
-wizard_page_apply(E_Wizard_Page *pg)
+wizard_page_apply(E_Wizard_Page *pg __UNUSED__)
 {
    return 1;
 }
